@@ -414,8 +414,8 @@ class KodexaPlatform:
     def get_object_instance(ref: str, object_type):
         object_type, object_type_metadata = resolve_object_type(object_type)
 
-        if 'type' in object_type_metadata and object_type_metadata['type'] is Taxonomy:
-            return KodexaPlatform.__build_object(ref, object_type_metadata, Taxonomy)
+        if 'type' in object_type_metadata:
+            return KodexaPlatform.__build_object(ref, object_type_metadata, object_type_metadata['type'])
 
         if object_type == 'stores':
             # We need to work out what type of store we have
